@@ -1,3 +1,4 @@
+# -*- coding:utf-8 -*-
+
 PROJECTNAME = "sc.pfg.brazilianfields"
-GLOBALS = globals()
-DEFAULT_ADD_CONTENT_PERMISSION = "PloneFormGen: Add Content"
\ No newline at end of file
+DEFAULT_ADD_CONTENT_PERMISSION = "PloneFormGen: Add Content"
